# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## \[Unreleased\]

## [0.1.1](https://github.com/cauliyang/DeepBioP/compare/deepbiop-fq-v0.1.0...deepbiop-fq-v0.1.1) - 2024-08-03

### Added

- Add deepbiop as a new package within the workspace

### Fixed

- Remove test.parquet file after test execution
